 Reahl is a web application framework that allows a Python programmer to work in 
 terms of useful abstractions - using a single programming language.

 The reahl-component-metadata package extends setuptools's setup() call to take an
 extra "component" keyword argument for packaging the extra metadata reahl-component
 requires.

 This package is very small and meant to be a build dependency of packages that are
 Reahl components.
